==> kubernetes-model-gatewayapi-6.1.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRequestRedirectFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRequestRedirectFilterFluent<A extends HTTPRequestRedirectFilterFluent<A>> extends Fluent<A>{
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  
  /**
   * This method has been deprecated, please use method buildPath instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPPathModifier getPath();
  public HTTPPathModifier buildPath();
  public A withPath(HTTPPathModifier path);
  public Boolean hasPath();
  public A withNewPath(String replaceFullPath,String replacePrefixMatch,String type);
  public HTTPRequestRedirectFilterFluent.PathNested<A> withNewPath();
  public HTTPRequestRedirectFilterFluent.PathNested<A> withNewPathLike(HTTPPathModifier item);
  public HTTPRequestRedirectFilterFluent.PathNested<A> editPath();
  public HTTPRequestRedirectFilterFluent.PathNested<A> editOrNewPath();
  public HTTPRequestRedirectFilterFluent.PathNested<A> editOrNewPathLike(HTTPPathModifier item);
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getScheme();
  public A withScheme(String scheme);
  public Boolean hasScheme();
  public Integer getStatusCode();
  public A withStatusCode(Integer statusCode);
  public Boolean hasStatusCode();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PathNested<N> extends Nested<N>,HTTPPathModifierFluent<HTTPRequestRedirectFilterFluent.PathNested<N>>{
    public N and();
    public N endPath();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRequestRedirectFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRequestRedirectFilterFluent<A extends HTTPRequestRedirectFilterFluent<A>> extends Fluent<A>{
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  
  /**
   * This method has been deprecated, please use method buildPath instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPPathModifier getPath();
  public HTTPPathModifier buildPath();
  public A withPath(HTTPPathModifier path);
  public Boolean hasPath();
  public A withNewPath(String replaceFullPath,String replacePrefixMatch,String type);
  public HTTPRequestRedirectFilterFluent.PathNested<A> withNewPath();
  public HTTPRequestRedirectFilterFluent.PathNested<A> withNewPathLike(HTTPPathModifier item);
  public HTTPRequestRedirectFilterFluent.PathNested<A> editPath();
  public HTTPRequestRedirectFilterFluent.PathNested<A> editOrNewPath();
  public HTTPRequestRedirectFilterFluent.PathNested<A> editOrNewPathLike(HTTPPathModifier item);
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getScheme();
  public A withScheme(String scheme);
  public Boolean hasScheme();
  public Integer getStatusCode();
  public A withStatusCode(Integer statusCode);
  public Boolean hasStatusCode();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PathNested<N> extends Nested<N>,HTTPPathModifierFluent<HTTPRequestRedirectFilterFluent.PathNested<N>>{
    public N and();
    public N endPath();
    
  }
  
}
